@@ -9,21 +9,37 @@ gNMI messags wrappers
 
 """
 
-import re
 import collections
-import json
-import sys
+import functools
 import itertools
+import json
+import re
+import warnings
 
 from abc import ABCMeta, abstractmethod
-from typing import Any, Dict, Generator, List, Optional, Tuple, Union
+from typing import Any, Generator, List, Optional, Tuple, Union
 
 import google.protobuf as _
 import grpc
 
+from gnmi.environments import GNMI_NO_DEPRECATED, GNMI_RC_PATH
+from gnmi.exceptions import GnmiDeprecationError
 from gnmi.proto import gnmi_pb2 as pb  # type: ignore
 from gnmi import util
 
+warnings.simplefilter("once", category=(PendingDeprecationWarning, DeprecationWarning))
+
+def deprecated(msg, klass=DeprecationWarning):
+    def decorator(func):
+        @functools.wraps(func)
+        def wrapper(*args, **kwargs):
+            if GNMI_NO_DEPRECATED:
+                raise GnmiDeprecationError(msg)
+            warnings.warn(msg, klass, stacklevel=2)
+            return func(*args, **kwargs)
+        return wrapper
+    return decorator
+
 class BaseMessage(metaclass=ABCMeta):
 
     def __init__(self, message):
@@ -69,7 +85,7 @@ class CapabilitiesResponse_(BaseMessage):
         return self.raw.gNMI_version
     version = gnmi_version
 
-@util.deprecated(("Deprecated in favour of using the "
+@deprecated(("Deprecated in favour of using the "
     "google.golang.org/genproto/googleapis/rpc/status"
     "message in the RPC response."))
 class Error_(BaseMessage):
@@ -131,7 +147,7 @@ class TypedValue_(BaseMessage):
 
         return val
 
-@util.deprecated("Message 'Value' is deprecated and may be removed in the future")
+@deprecated("Message 'Value' is deprecated and may be removed in the future")
 class Value_(BaseMessage):
 
     @property
@@ -184,22 +200,23 @@ class Update_(BaseMessage):
         return Path_(self.raw.path)
 
     @property
-    def val(self):
-        return TypedValue_(self.raw.val)
+    def val(self) -> Optional[TypedValue_]:
+        if self.raw.HasField('val'):
+            return TypedValue_(self.raw.val)
     
     @property
-    @util.deprecated("Field 'value' has been deprecated and may be removed in the future")
-    def value(self):
-        return Value_(self.raw.value)
+    def value(self) -> Optional[Value_]:
+        if self.raw.HasField('value'):
+            return Value_(self.raw.value)
     
     @property
     def duplicates(self):
         return self.raw.duplicates
 
-    def get_value(self):
-        try:
+    def get_value(self) -> Union[TypedValue_, Value_]:
+        if self.val:
             return self.val.extract_val()
-        except ValueError:
+        elif self.value:
             return self.value.extract_val()
 
     @classmethod
@@ -242,7 +259,7 @@ class Notification_(IterableMessage):
         return self.raw.timestamp
 
     @property
-    def update(self):
+    def update(self) -> Generator[Update_, None, None]:
         for u in self.raw.update:
             yield Update_(u)
 
@@ -263,9 +280,9 @@ class GetResponse_(IterableMessage):
     notifications = notification
         
     @property
-    @util.deprecated("Field 'error' has been deprecated and may be removed in the future")
     def error(self) -> Error_:
-        return Error_(self.raw.error)
+        if self.raw.HasField('error'):
+            return Error_(self.raw.error)
 
 class UpdateResult_(BaseMessage):
     _OPERATION = [
@@ -290,7 +307,7 @@ class UpdateResult_(BaseMessage):
         return Path_(self.raw.path)
 
     @property
-    @util.deprecated(("Deprecated timestamp for the UpdateResult, this field has been "
+    @deprecated(("Deprecated timestamp for the UpdateResult, this field has been "
         "replaced by the timestamp within the SetResponse message, since "
         "all mutations effected by a set should be applied as a single "
         "transaction."))
@@ -298,9 +315,9 @@ class UpdateResult_(BaseMessage):
         return self.raw.timestamp
 
     @property
-    @util.deprecated("Field 'error' has been deprecated and may be removed in the future")
-    def error(self) -> Error_:
-        return Error_(self.raw.error)
+    def error(self) -> Optional[Error_]:
+        if self.raw.HasField('error'):
+            return Error_(self.raw.error)
 
 class SetResponse_(IterableMessage):
 
@@ -319,9 +336,9 @@ class SetResponse_(IterableMessage):
     responses = response
 
     @property
-    @util.deprecated("Field 'error' has been deprecated and may be removed in the future")
-    def error(self) -> Error_:
-        return Error_(self.raw.error)
+    def error(self) -> Optional[Error_]:
+        if self.raw.HasField('error'):
+            return Error_(self.raw.error)
 
 class SubscribeResponse_(BaseMessage):
     r"""Represents a gnmi.SubscribeResponse message
@@ -340,9 +357,9 @@ class SubscribeResponse_(BaseMessage):
         return Notification_(self.raw.update)
 
     @property
-    @util.deprecated("Field 'error' has been deprecated and may be removed in the future")
-    def error(self) -> Error_:
-        return Error_(self.raw.error)
+    def error(self) -> Optional[Error_]:
+        if self.raw.HasField('error'):
+            return Error_(self.raw.error)
 
 class PathElem_(BaseMessage):
     r"""Represents a gnmi.PathElem message
@@ -392,9 +409,10 @@ class Path_(IterableMessage):
     elems = elem
 
     @property
-    @util.deprecated("Field 'element' has been deprecated and may be removed in the future")
     def element(self) -> Generator[str, None, None]:
         for e in self.raw.element:
+            warnings.warn("Field 'element' has been deprecated and may be removed in the future",
+                DeprecationWarning, stacklevel=2)
             yield e
     elements = element
 
@@ -414,10 +432,10 @@ class Path_(IterableMessage):
             for key, val in elem.key.items():
                 val = util.escape_string(val, "]")
                 path += "[" + key + "=" + val + "]"
-        
+
         if not path:
             path =  "/" + "/".join(self.element)
-        
+
         if self.origin:
             path = ":".join([self.origin, path])
         return path
